DistanceFunction

Enum DistanceFunction 

pub enum DistanceFunction {
    Frobenius(ScalarDistance),
    MeanEuclidean(ScalarDistance),
    MeanManhattan(ScalarDistance),
    Iou(VectorizedDistance),
    ScipyEuclidean(ScipyDistance),
    ScipySqeuclidean(ScipyDistance),
    ScipyManhattan(ScipyDistance),
    ScipyCosine(ScipyDistance),
    ScipyChebyshev(ScipyDistance),
}
Enum-based distance function for static dispatch.

This avoids Box<dyn Distance> vtable overhead by using an enum with inline implementations. Use distance_function_by_name() to create instances.

Variants



Frobenius(ScalarDistance)



MeanEuclidean(ScalarDistance)



MeanManhattan(ScalarDistance)



Iou(VectorizedDistance)



ScipyEuclidean(ScipyDistance)



ScipySqeuclidean(ScipyDistance)



ScipyManhattan(ScipyDistance)



ScipyCosine(ScipyDistance)



ScipyChebyshev(ScipyDistance)

Implementations

Source

impl DistanceFunction

pub fn get_distances( &self, objects: &[&TrackedObject], candidates: &[&Detection], ) -> DMatrix<f64>

Get distances between objects and candidates.

pub fn get_distances_objects( &self, objects: &[&TrackedObject], candidates: &[&TrackedObject], ) -> DMatrix<f64>

Get distances between two sets of TrackedObjects (for ReID matching).

For built-in distance functions, creates temporary Detections from candidate estimates. For custom Python callables, this requires the reid_distance_function to accept (TrackedObject, TrackedObject) -> float (not Detection, TrackedObject).